[PATCH 5/7] mmc: host: sdhci-esdhc-imx: fix broken email address

From: Wolfram Sang
Date: Mon Apr 20 2015 - 09:52:12 EST


My Pengutronix address is not valid anymore, redirect people to the Pengutronix
kernel team.

Reported-by: Harald Geyer <harald@xxxxxxxxx>
Signed-off-by: Wolfram Sang <wsa@xxxxxxxxxxxxx>
Acked-by: Robert Schwebel <r.schwebel@xxxxxxxxxxxxxx>
---
These patches shall go via the individual subsystem trees.

drivers/mmc/host/sdhci-esdhc-imx.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/mmc/host/sdhci-esdhc-imx.c b/drivers/mmc/host/sdhci-esdhc-imx.c
index 10ef8244a23963..3d7aa50e04578a 100644
--- a/drivers/mmc/host/sdhci-esdhc-imx.c
+++ b/drivers/mmc/host/sdhci-esdhc-imx.c
@@ -4,7 +4,7 @@
* derived from the OF-version.
*
* Copyright (c) 2010 Pengutronix e.K.
* Author: Wolfram Sang <w.sang@xxxxxxxxxxxxxx>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -1173,5 +1173,5 @@ static struct platform_driver sdhci_esdhc_imx_driver = {
module_platform_driver(sdhci_esdhc_imx_driver);

MODULE_DESCRIPTION("SDHCI driver for Freescale i.MX eSDHC");
-MODULE_AUTHOR("Wolfram Sang <w.sang@xxxxxxxxxxxxxx>");
+MODULE_AUTHOR("Wolfram Sang <kernel@xxxxxxxxxxxxxx>");
MODULE_LICENSE("GPL v2");
@@ -4,7 +4,7 @@
*
* Copyright (c) 2010 Pengutronix e.K.
- * Author: Wolfram Sang <w.sang@xxxxxxxxxxxxxx>
+ * Author: Wolfram Sang <kernel@xxxxxxxxxxxxxx>
*
* This program is free software; you can redistribute it and/or modify
--
2.1.4

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/